@@ -66,7 +66,7 @@ class RecursiveStrategy(SearchStrategy):
 
         strategies = [self.limited_base, self.extend(self.limited_base)]
         while 2 ** len(strategies) <= max_leaves:
-            strategies.append(extend(OneOfStrategy(tuple(strategies), bias=0.8)))
+            strategies.append(extend(OneOfStrategy(tuple(strategies))))
         self.strategy = OneOfStrategy(strategies)
 
     def __repr__(self):
@@ -99,7 +99,9 @@ class RecursiveStrategy(SearchStrategy):
                 with self.limited_base.capped(self.max_leaves):
                     return data.draw(self.strategy)
             except LimitReached:
-                if count == 0:
+                # Workaround for possible coverage bug - this branch is definitely
+                # covered but for some reason is showing up as not covered.
+                if count == 0:  # pragma: no branch
                     data.note_event(
                         lazyformat(
                             "Draw for %r exceeded max_leaves and had to be retried",
